# coding: utf-8

"""
    URLR API Reference

    API powering the features of URLR.<br><br>Note that in order to facilitate integration, we provide SDKs for various languages at https://github.com/URLR.<br><br>Key API principles:<br>         <ul><li>All dates follow **ISO-8601** format</li><li>Most errors follow **RFC 9457** standard</li><li>All responses are delivered in English</li></ul>

    The version of the OpenAPI document: 1.5
    Contact: contact@urlr.me
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "urlr"
VERSION = "2.7.0"
PYTHON_REQUIRES = ">= 3.8"
REQUIRES = [
    "urllib3 >= 1.25.3, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="Python client for URLR",
    author="URLR",
    author_email="contact@urlr.me",
    url="",
    keywords=["link shortener", "api", "sdk", "client"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT",
    long_description_content_type='text/markdown',
    long_description="""\
    API powering the features of URLR.&lt;br&gt;&lt;br&gt;Note that in order to facilitate integration, we provide SDKs for various languages at https://github.com/URLR.&lt;br&gt;&lt;br&gt;Key API principles:&lt;br&gt;         &lt;ul&gt;&lt;li&gt;All dates follow **ISO-8601** format&lt;/li&gt;&lt;li&gt;Most errors follow **RFC 9457** standard&lt;/li&gt;&lt;li&gt;All responses are delivered in English&lt;/li&gt;&lt;/ul&gt;
    """,  # noqa: E501
    package_data={"urlr": ["py.typed"]},
)